@@ -57,12 +57,7 @@ const ENIG_UNLIMITED_BUFFER_SIZE = -1;
 const ENIG_KEY_BUFFER_SIZE = 64000;
 
 const ENIG_PROCESSINFO_CONTRACTID = "@mozilla.org/xpcom/process-info;1";
-const ENIG_IPCBUFFER_CONTRACTID   = "@mozilla.org/ipc/ipc-buffer;1";
-const ENIG_PIPEFILTERLISTENER_CONTRACTID = "@mozilla.org/process/pipe-filter-listener;1";
 const ENIG_ENIGMAIL_CONTRACTID    = "@mozdev.org/enigmail/enigmail;1";
-const ENIG_ENIGMIMELISTENER_CONTRACTID = "@mozilla.org/enigmail/mime-listener;1";
-const ENIG_ENIGMIMESERVICE_CONTRACTID = "@mozdev.org/enigmail/enigmimeservice;1";
-const ENIG_ENIGMIMEVERIFY_CONTRACTID = "@mozilla.org/enigmail/mime-verify;1";
 const ENIG_STRINGBUNDLE_CONTRACTID = "@mozilla.org/intl/stringbundle;1";
 const ENIG_LOCAL_FILE_CONTRACTID = "@mozilla.org/file/local;1";
 const ENIG_DIRSERVICE_CONTRACTID = "@mozilla.org/file/directory_service;1";
@@ -630,7 +625,7 @@ function EnigRevokeKey(keyId, userId, callbackFunc) {
   var tmpDir=EnigGetTempDir();
 
   try {
-    var revFile = ENIG_C[ENIG_LOCAL_FILE_CONTRACTID].createInstance(ENIG_I.nsILocalFile);
+    var revFile = ENIG_C[ENIG_LOCAL_FILE_CONTRACTID].createInstance(EnigGetLocalFileApi());
     revFile.initWithPath(tmpDir);
     if (!(revFile.isDirectory() && revFile.isWritable())) {
       EnigAlert(EnigGetString("noTempDir"));
@@ -663,6 +658,9 @@ function EnigRevokeKey(keyId, userId, callbackFunc) {
     });
 }
 
+function EnigGetLocalFileApi() {
+  return EnigmailCommon.getLocalFileApi();
+}
 
 function EnigShowPhoto (keyId, userId, photoNumber) {
   EnigmailFuncs.showPhoto(window, keyId, userId, photoNumber);
